/*!
	\file	IAtlAnimatedObjectInstance.h
	\date	22 06 06
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\brief	Header for the IAtlAnimatedObjectInstance interface
*/
#ifndef		IAtlAnimatedObjectInstance_h
#define		IAtlAnimatedObjectInstance_h


#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef CAtlProperty_h
	#include "CAtlProperty.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif

namespace AvAtl {

// Forward declaration
class IAtlObjectInstance;

/// List of properties
typedef TAtlObjectMgr<CAtlProperty>			AtlPropertyMgr;

/*!
	\interface	IAtlAnimatedObjectInstance
	\date		22 06 06
	\author		Abvent R&D Copyright (C) 2006
	\author		Guillaume Boulet-Gercourt
	\brief		interface for access to animated object instance.
*/
class	IAtlAnimatedObjectInstance
{
public:

	/// get the current frame of this object
	virtual int		getCurrentFrame() const = 0;

	/// set the current frame of this object
	virtual void	setCurrentFrame(int inFrame) = 0;

	/// get the current take of this object
	virtual int		getCurrentTake() const = 0;

	/// set the current take of this object
	virtual	void	setCurrentTake(int inTake) = 0;

	/// get the real duration of the current animation of instance
	virtual int		getRealAnimationDuration() const = 0;

	/// set the real duration of the current animation of instance
	virtual void	setRealAnimationDuration(int inValue) = 0;

	/// get the start frame for the current take
	virtual int		getStartFrame() const = 0;

	/// set the start frame for the current take
	virtual void	setStartFrame(int inFrame) = 0;

	/// Get the localy affected properties of the Atl Animated Object.
	/** For consulting */
	virtual const AtlPropertyMgr*		getOverloadedPropertyMgr() const = 0;

	/// Get the localy affected properties of the Atl Animated Object.
	/** For setting */
	virtual AtlPropertyMgr*				getOverloadedPropertyMgr() = 0;

	/// Type conversion to IAtlObjectInstance
	virtual const IAtlObjectInstance*	asObjectInstance() const = 0;

	/// Type conversion to IAtlObjectInstance
	virtual IAtlObjectInstance*			asObjectInstance() = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsability of the CAtlMgr class.*/
	virtual ~IAtlAnimatedObjectInstance() {}
};


} // namespace AvAtl

#endif // IAtlAnimatedObjectInstance_h
