/** \file
 * Header for the IAtlPanoLinkV2 interface
 *
 * \author Abvent R&D Copyright (c) 2011
 * \author Christophe
 * \date 18/02/2011
 */

#ifndef IAtlPanoLinkV2_h
#define IAtlPanoLinkV2_h

#include <vector>

#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif
#ifndef CAtlVector_h
	#include "CAtlVector.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// List of panorama nodes
typedef TAtlObjectMgr<class IAtlPanoLinkV2>	AtlPanoLinkV2Mgr;


/// Information on link between camera.
/** \interface IAtlPanoLinkV2 
 *	The information on a link
 *
 * \author Abvent R&D Copyright (c) 2011
 * \author Christophe
 * \date 18/02/2011
 */
class IAtlPanoLinkV2
{
protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class.*/
	virtual							~IAtlPanoLinkV2() {}

public:
	/// Put an XML representation of the link inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the link with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Return the node 1 of this node.
	virtual tUUID					getStartNode() const = 0;
	/// Set the node 1 of this node.
	virtual void					setStartNode(tUUID inIndex) = 0;

	/// Return the node 2 of this node.
	virtual tUUID					getEndNode() const = 0;
	/// Set the node 2 of this node.
	virtual void					setEndNode(tUUID inIndex) = 0;

	/// Return the path describing the shape of the link.
	virtual tUUID					get3DPath() const = 0;
	/// Set the path for the link.
	virtual void					set3DPath(tUUID inIndex) = 0;

	/// Return the number of intermediate panoramas computed on the path (including start and end points in the count)
	virtual int						getNbPoints() const = 0;
	/// Return requested point (panorama) at given index
	virtual float					getPoint(int inIndex) const = 0;
	
	/// Get the id of this link
	virtual tUUID					getId() const = 0;
	/// Set the id of this link
	virtual void					setId(tUUID inId) = 0;
};


} // namespace  AvAtl

#endif
