/** \file
 * Header for the interface IAtlString
 *
 * \author Abvent R&D Copyright (c) 2004
 * \author Richard Young
 * \version 1.0
 * \date 14/10/2004
 */

#ifndef IAtlString_h
#define IAtlString_h

// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef ISO639_h
	#include "ISO639.h"
#endif


namespace  AvAtl {


/// Interface for localizable string.
/** \interface IAtlString 
 *	Class that contains localizable string.
 *
 * \author Abvent R&D Copyright (c) 2004
 * \author Richard Young
 * \version 1.0
 * \date 14/10/2004
 */
class IAtlString
{
public:
	/// Initialize a string with another string
	virtual void					initWithAtlString(const IAtlString& inString) = 0;

	/// Return the string for the default language
	/** Will return the first availiable string if the default language string doesn't exist. */
	virtual tUtf8					getString() const = 0;
	/// Set the string for the default language
	virtual void					setString(tUtf8 inString) = 0;

	/// Return the string for the specified language
	/** Return NULL if the string for this language isn't specified */
	virtual tUtf8					getString(Abvent::eISO639 inLanguage) const = 0;
	/// Set the string for the specified language
	/** If inString is NULL, the string for this language will be removed */
	virtual void					setString(Abvent::eISO639 inLanguage, tUtf8 inString) = 0;

	/// Return the number of languages for this string
	virtual unsigned int			getNbLanguages() const = 0;
	/// Return the inIndex languages
	virtual Abvent::eISO639			getLanguage(unsigned int inIndex) const = 0;

	/// Reset all recorded strings
	virtual void					resetAllStrings() = 0;
protected:
	/** You must not create or delete objects of this class.
    This is the responsibility of the CAtlMgr class. */
									~IAtlString() {}
};


} // namespace AvAtl

#endif
