/**
 \file IChessNode.h
 
 Interface class for checker TCE node.
 
 \verbatim
 
 File			:	IChessNode.h
 Author			:	Richard Young
 Creation date	:	28/04/2001
 Description	:	The interface IChessNode is the class for checker node in tce tree.
 
 Modifications	:
 
 \endverbatim
 */


#ifndef IChessNode_h
#define IChessNode_h


#ifndef CAtlVector_h
	#include "CATL/CAtlVector.h"
#endif
#ifndef ITable_h
	#include "ITable.h"
#endif


namespace AvAtl{


// Forward declarations.
class ITCENode;
class ITable;


/// The interface IChessNode is the class for leaf node in tce tree
/** \interface IChessNode
 *
 * \author Abvent R&D Copyright (c) 2001
 * \author Richard Young
 * \version 1.0
 * \date 28/04/2001
 */
class IChessNode
{
public:
	// For ATL library internal usage only.
#ifdef ITCENode_h
	enum { mType = ITCENode::eChessNode };
#endif

	enum EChessGeometry
	{
	    eCG_Cylinder,			// Was CYLINDER_GEOMETRY
	    eCG_Sphere,				// Was SPHERE_GEOMETRY
	    eCG_Cube				// Was CUBE_GEOMETRY
	};

	// Return the node of this Chess.
	virtual const ITCENode*		asNode() const = 0;
	virtual ITCENode*			asNode() = 0;

	// set/get origin of the chess texture in world coordinates
	virtual const CAtlVector&	getOrigin() const = 0;
	virtual void				setOrigin(const CAtlVector& origin) = 0;

	// set/get x axis of the chess texture in world coordinates
	virtual const CAtlVector&	getXAxis() const = 0;
	virtual void				setXAxis(const CAtlVector& axe) = 0;

	// set/get y axis of the chess texture in world coordinates
	virtual const CAtlVector&	getYAxis() const = 0;
	virtual void				setYAxis(const CAtlVector& axe) = 0;

	// set/get z axis of the chess texture in world coordinates
	virtual const CAtlVector&	getZAxis() const = 0;
	virtual void				setZAxis(const CAtlVector& axe) = 0;

	// set/get the size of the tiles in world coordinates
	virtual const CAtlVector&	getSize() const = 0;
	virtual void				setSize(const CAtlVector& size) = 0;

	// set/get proportion of white/black tiles
	virtual const CAtlVector&	getProportion() const = 0;
	virtual void				setProportion(const CAtlVector& proportion) = 0;

	virtual bool				getCheckerFlag() const = 0;
	virtual void				setCheckerFlag(bool flag) = 0;

	virtual bool				getSmoothFlag() const = 0;
	virtual void				setSmoothFlag(bool smooth) = 0;

	virtual EChessGeometry		getGeometry() const = 0;
	virtual void				setGeometry(EChessGeometry geo) = 0;

	virtual const ITable*		getTable1() const = 0;
	virtual ITable*				getTable1() = 0;

	virtual const ITable*		getTable2() const = 0;
	virtual ITable*				getTable2() = 0;

	virtual const ITable*		getTable3() const = 0;
	virtual ITable*				getTable3() = 0;

protected:
	// Don't delete, use node refcount
								~IChessNode() {};
};


} // namespace  AvAtl

#endif
