/**
 \file IFresnelDiffuseNode.h
 
 Interface class for leaf TCE node.
 
 \verbatim
 
 File			:	IFresnelDiffuseNode.h
 Author			:	Richard Young
 Creation date	:	28/04/2001
 Description	:	The interface IFresnelDiffuseNode is the class for balanced fresnel node in tce tree.
 
 Modifications	:
 
 \endverbatim
 */


#ifndef IFresnelDiffuseNode_h
#define IFresnelDiffuseNode_h


namespace AvAtl{


// Forward declarations.
class ITCENode;


/// The interface IFresnelDiffuseNode is the class for balanced fresnel node in tce tree
/** \interface IFresnelDiffuseNode
 * Same as IFresnelDiffuseNode but using the diffuse component (balance between difuse and reflection components)
 *
 * \author Abvent R&D Copyright (c) 2001
 * \author Richard Young
 * \version 1.0
 * \date 28/04/2001
 */
class IFresnelDiffuseNode
{
public:
	enum { mType = ITCENode::eFresnelDiffuseNode };

	/// Return the node of this fresnel node.
	virtual const ITCENode*		asNode() const = 0;
	virtual ITCENode*			asNode() = 0;

	/// The minimal reflection value (at 90 degres)
	virtual double				getMinReflection() const = 0;
	virtual void				setMinReflection(double inMinReflection) = 0;

	/// The power factor of the curve
	virtual double				getPowerFactor() const = 0;
	virtual void				setPowerFactor(double inPowerFactor) = 0;

protected:
	/// Don't delete, use node refcount
								~IFresnelDiffuseNode() {};
};


} // namespace  AvAtl

#endif
